import request from '@/utils/request'
import { praseStrEmpty } from '@/utils/common'
import Qs from 'qs'
// 查询用户列表
export function listUser(query) {
  return request({
    url: '/system/user/list',
    method: 'get',
    params: query
  })
}
// selectUserIdsListDept 新查询用户接-口
export function selectUserIdsListDept(params) {
  return request({
    url: '/system/user/listByDept',
    method: 'post',
    params
  })
}
// 查询用户详细
export function getUser(userId) {
  return request({
    url: '/system/user/' + praseStrEmpty(userId),
    method: 'get'
  })
}

// 新增用户
export function addUser(data) {
  data = Qs.stringify(data)
  return request({
    url: '/system/user/add',
    method: 'post',
    data,
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded'
    }
  })
}

// 修改用户
export function updateUser(data) {
  // const businessId = data.businessId
  data = Qs.stringify(data)
  return request({
    url: '/system/user/update',
    method: 'put',
    data: data,
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded'
    }
  })
}

// 删除用户
export function delUser(userId) {
  return request({
    url: '/system/user/deleteLogical/' + userId,
    method: 'delete'
  })
}

// 用户密码重置
export function resetUserPwd(businessId, password) {
  const data = {
    businessId,
    password
  }
  return request({
    url: '/system/user/updatePwd',
    method: 'put',
    params: data
  })
}

// 用户状态修改
export function changeUserStatus(businessId, flag) {
  const data = {
    businessId,
    flag
  }
  return request({
    url: '/system/user/changeStatus',
    method: 'put',
    params: data
  })
}

// 查询用户个人信息
export function getUserProfile() {
  return request({
    url: '/system/user/profile',
    method: 'get'
  })
}

// 修改用户个人信息
export function updateUserProfile(data) {
  return request({
    url: 'system/user/profile',
    method: 'put',
    data: data
  })
}

// 用户密码重置
export function updateUserPwd(data) {
  return request({
    url: '/system/user/updatePwd',
    method: 'put',
    params: data
  })
}

// 导出用户
export function exportUser(query) {
  return request({
    url: '/system/user/export',
    method: 'get',
    params: query,
    responseType: 'blob'
  })
}

// 用户头像上传
export function uploadAvatar(data) {
  return request({
    url: '/system/user/profile/avatar',
    method: 'post',
    data: data
  })
}

// 下载用户导入模板
export function importTemplate(params) {
  return request({
    url: '/system/user/importTemplate',
    method: 'get',
    responseType: 'blob',
    params
  })
}
// 导入用户信息
export function importExcel(data) {
  return request({
    url: '/system/user/importExcel',
    method: 'post',
    headers: {
      'Content-Type': 'multipart/form-data'
    },
    transformRequest: [(data) => {
      return data
    }],
    data
  })
}

// 下载错误文件
export function uploadFalseFile(params) {
  params = Qs.stringify(params)
  return request({
    url: '/system/user/downFalseFile',
    method: 'post',
    data: params,
    responseType: 'blob'
  })
}

// 控制用户能否登录
export function userLoginManage(data) {
  return request({
    url: '/system/user/updateAllowLogin',
    method: 'post',
    data
  })
}
